@@ -29,14 +29,15 @@ randomCPT <- function(object, states=c("yes", "no")){
 .namesDimnames <- function(x)
     names(dimnames(x))
 
-setSliceValue <- function(x, slice, complement=FALSE, value=0){
-    margin <- names(slice)
-    level  <- unlist(slice, use.names=FALSE)
-    idx <- tableGetSliceIndex(x, margin = margin, level = level,
-                              complement = complement)
-    x[idx] <- value
-    x
-}
+## ' @export 
+## setSliceValue <- function(x, slice, complement=FALSE, value=0){
+    ## margin <- names(slice)
+    ## level  <- unlist(slice, use.names=FALSE)
+    ## idx <- tableGetSliceIndex(x, margin = margin, level = level,
+                              ## complement = complement)
+    ## x[idx] <- value
+    ## x
+## }
 
 
 listify_dots <- function(args){
